# MGSurvE: Mosquito Gene SurveillancE


MGSurvE is a project oriented towards the optimization of traps' placement in complex heterogeneous landscapes in an effort to minimize the time to detection of genetic variants of interest.



**Under Construction** :construction: **Please check back in a couple of weeks!**

To install the package's latest stable version, run:

```
pip install MGSurvE
conda install -c conda-forge cartopy
```


[![PyPI version](https://badge.fury.io/py/MGSurvE.svg)](https://badge.fury.io/py/MGSurvE)[![License: GPL v2](https://img.shields.io/badge/License-GPL_v2-blue.svg)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html)![Travis Build](https://app.travis-ci.com/Chipdelmal/MGSurvE.svg?branch=main)[![Open Source Love](https://badges.frapsoft.com/os/v1/open-source.png?v=103)](https://github.com/ellerbrock/open-source-badges/)

<!--![Git Build](https://github.com/Chipdelmal/MGSurvE/actions/workflows/main.yml/badge.svg)-->

![landscape](https://github.com/Chipdelmal/MGSurvE/raw/main/img/demo.jpg)


Please have a look at the [documentation](https://chipdelmal.github.io/MGSurvE/) for more info and our [pypi](https://pypi.org/project/MGSurvE/) package for installation and versions.


[<img src="https://pypi.org/static/images/logo-large.6bdbb439.svg" height="50px" align="middle">](https://pypi.org/project/MGSurvE/)

# Features and Development

- [x] Different point-types
- [x] Random point-process landscape generators
- [x] Customizable movement kernels
- [x] Customizable trap attractiveness kernels
- [x] Integrated plotting routines
- [x] GA Optimization routines
- [x] Directed network plotting routines
- [x] Demos and Examples
- [x] Immovable traps
- [x] Different attractiveness levels at specific point-type transitions
- [x] Different movement kernels for male and female mosquitos
- [x] Different trap attractiveness levels for male and female mosquitos 
- [x] Thorough timing benchmarks
- [x] Support for xy coordinate systems
- [ ] Support for lat-lon coordinate systems
- [x] Integrated Map-plotting routines
- [ ] Lumpability aggregation algorithm
- [ ] Repellency effects
- [ ] Multi-threaded processing

# Authors and Funders

<img src="https://raw.githubusercontent.com/Chipdelmal/pyMSync/master/media/pusheen.jpg" height="125px" align="middle"><img src="https://github.com/Chipdelmal/MGSurvE/blob/main/img/MGSurvE_Logo.png?raw=true" height="125px" align="middle"> <br><br>

* Lead and Dev: [Héctor M. Sánchez C.](https://chipdelmal.github.io/blog/)
* Active Devs: Elijah Bartolome
* PIs: [David L. Smith](http://www.healthdata.org/about/david-smith), [John M. Marshall](https://publichealth.berkeley.edu/people/john-marshall/)

<img src="https://github.com/Chipdelmal/MGSurvE/raw/main/img/berkeley.jpg" height="25px"> &nbsp; <img src="https://github.com/Chipdelmal/MGSurvE/raw/main/img/IHME.jpg" height="25px"> &nbsp;  <img src="https://github.com/Chipdelmal/MGSurvE/raw/main/img/IGI.png" height="25px"> &nbsp; <img src="https://github.com/Chipdelmal/MGSurvE/raw/main/img/DARPA.jpg" height="25px"> &nbsp; <img src="https://github.com/Chipdelmal/MGSurvE/raw/main/img/gates.jpg" height="25px">

<br>